@@ -166,27 +166,35 @@ def make_attn_forward(context: Context, attn_precision='fp16'):
         r1 = torch.zeros(q.shape[0], q.shape[1], v.shape[2], device=q.device, dtype=q.dtype)
         steps = get_steps(q, k)
         slice_size = q.shape[1] // steps if (q.shape[1] % steps) == 0 else q.shape[1]
-        for i in range(0, q.shape[1], slice_size):
-            end = i + slice_size
-            if attn_precision == "fp32":
-                with torch.autocast(enabled=False, device_type=autocast_device):
-                    q, k = q.float(), k.float()
+        try:
+            for i in range(0, q.shape[1], slice_size):
+                end = i + slice_size
+                if attn_precision == "fp32":
+                    with torch.autocast(enabled=False, device_type=autocast_device):
+                        q, k = q.float(), k.float()
+                        s1 = einsum('b i d, b j d -> b i j', q[:, i:end], k)
+                else:
                     s1 = einsum('b i d, b j d -> b i j', q[:, i:end], k)
-            else:
-                s1 = einsum('b i d, b j d -> b i j', q[:, i:end], k)
 
-            s2 = s1.softmax(dim=-1, dtype=q.dtype)
-            del s1
+                try:
+                    s2 = s1.softmax(dim=-1, dtype=q.dtype)
+                finally:
+                    del s1
 
-            r1[:, i:end] = einsum('b i j, b j d -> b i d', s2, v)
-            del s2
-
-        del q, k, v
+                try:
+                    r1[:, i:end] = einsum('b i j, b j d -> b i d', s2, v)
+                finally:
+                    del s2
+        finally:
+            del q, k, v
 
         r2 = rearrange(r1, '(b h) n d -> b n (h d)', h=h)
-        del r1
+        try:
+            out = self.to_out(r2)
+        finally:
+            del r1, r2
 
-        return self.to_out(r2)
+        return out
 
     return forward
 
